=============
PyElegantSDDS
=============


PyElegantSDDS is a Python wrapper around a Singularity container with SDDS and Parallel
Elegant installed in it. It uses this container to build and run templates for common task in 
particle tracking for accelerators.

* Free software: MIT license
* Documentation: https://PyElegantSDDS.readthedocs.io.


Features
--------

* SDDS commands
* Elegant commands (twiss, track, FMA, DA, ...)
* Run simulations in just a few lines of Python code. 
* Generate Hyper-cubical and Hyper-Spherical distributions for tracking
* Quick plotting using SDDS tools

